import random
import string

# copied long time ago from a stack overflow answer
from io import BytesIO, StringIO
from pathlib import Path


def id_generator(size=6, chars=string.ascii_uppercase + string.digits):
    return ''.join(random.choice(chars) for _ in range(size))


def generate_id(path, dir=False, **kwargs):
    file = path.stem
    parent_path = path.parent
    suffix = path.suffix
    id = ''
    while (parent_path / f'{file}{id}{suffix}').is_dir() if dir else (parent_path / f'{file}{id}{suffix}').is_file():
        id = id_generator(**kwargs)
    return f'{file}{id}{suffix}'


def io_mkdir(path, m='', **kwargs):
    if path is None:
        raise ValueError

    path = Path(path)
    name = generate_id(path, dir=True, **kwargs)
    (path.parent / name).mkdir()
    return


def io_writer(path, data=None, m='', **kwargs):
    if path is None:
        raise ValueError

    path = Path(path)
    if data is None:
        raise ValueError
    if type(data) is str:
        mo = 'w'
    elif type(data) is bytes:
        try:
            data = data.decode()
            mo = 'w'
        except (UnicodeDecodeError, AttributeError):
            mo = 'wb'
    else:
        if type(data) is BytesIO:
            mo = 'wb'
        elif type(data) is StringIO:
            mo = 'w'
        else:
            raise ValueError
        data = data.read()
    name = generate_id(path, **kwargs)

    if m == '':
        m = mo
    with open(path.parent / name, m) as file:
        file.write(data)
    return



from distutils.core import setup
from pathlib import Path

try:
    this_directory = Path(__file__).absolute().parent
    with open((this_directory / 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
except FileNotFoundError:
    long_description = ''

setup(
    name='io-uuid',
    packages=['iouuid'],
    version='0.0.1',
    license='BSD 3-Clause',
    description='A file name generator',
    author='LeLunZ',
    author_email='l.accounts@pm.me',
    url='https://github.com/LeLunZ/iouuid',
    download_url='https://github.com/LeLunZ/iouuid/archive/0.0.1.tar.gz',
    keywords=['iouuid', 'uuid', 'name generator', 'file name generator'],
    install_requires=[],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    long_description=long_description,
    long_description_content_type='text/markdown'
)
